==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-english.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Your Name");
define("_OK","Ok!");
define("_COMMENT","comment");
define("_CONFIGURE","Configure");
define("_LOGINCREATE","Login/Create an Account");
define("_THRESHOLD","Threshold");
define("_NOCOMMENTS","No Comments");
define("_NESTED","Nested");
define("_FLAT","Flat");
define("_THREAD","Thread");
define("_OLDEST","Oldest First");
define("_NEWEST","Newest First");
define("_HIGHEST","Highest Scores First");
define("_COMMENTSWARNING","The comments are owned by the poster. We aren't responsible for their content.");
define("_SCORE","Score:");
define("_USERINFO","User Info");
define("_READREST","Read the rest of this comment...");
define("_REPLY","Reply to This");
define("_REPLYMAIN","Post Comment");
define("_NOSUBJECT","No Subject");
define("_NOANONCOMMENTS","No Comments Allowed for Anonymous, please <a href=\"modules.php?name=Your_Account\">register</a>");
define("_PARENT","Parent");
define("_ROOT","Root");
define("_UCOMMENT","Comment");
define("_ALLOWEDHTML","Allowed HTML:");
define("_POSTANON","Post Anonymously");
define("_EXTRANS","Extrans (html tags to text)");
define("_HTMLFORMATED","HTML Formated");
define("_PLAINTEXT","Plain Old Text");
define("_ONN","on...");
define("_SUBJECT","Subject");
define("_SURVEYCOM","Survey Comment Post");
define("_SURVEYCOMPRE","Survey Comment Post Preview");
define("_NOTRIGHT","Something is not right with passing a variable to this function. This message is just to keep things from messing up down the road");
define("_DIRECTCOM","Direct Survey Comment...");
define("_SENDAMSG","Send a Message");
define("_PASTSURVEYS","Past Surveys");



define("_LVOTES","votes");
define("_TOTALVOTES","Total Votes:");
define("_VOTING","Voting Booth");
define("_OTHERPOLLS","Other Polls");
define("_CURRENTSURVEY","Current Survey");
define("_CURRENTPOLLRESULTS","Current Poll Results");
define("_PREVIEW","Preview");
define("_REFRESH","Refresh");
define("_SURVEYS","Surveys");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-english.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Your Name");
define("_OK","Ok!");
define("_COMMENT","comment");
define("_CONFIGURE","Configure");
define("_LOGINCREATE","Login/Create an Account");
define("_THRESHOLD","Threshold");
define("_NOCOMMENTS","No Comments");
define("_NESTED","Nested");
define("_FLAT","Flat");
define("_THREAD","Thread");
define("_OLDEST","Oldest First");
define("_NEWEST","Newest First");
define("_HIGHEST","Highest Scores First");
define("_COMMENTSWARNING","The comments are owned by the poster. We aren't responsible for their content.");
define("_SCORE","Score:");
define("_USERINFO","User Info");
define("_READREST","Read the rest of this comment...");
define("_REPLY","Reply to This");
define("_REPLYMAIN","Post Comment");
define("_NOSUBJECT","No Subject");
define("_NOANONCOMMENTS","No Comments Allowed for Anonymous, please <a href=\"modules.php?name=Your_Account\">register</a>");
define("_PARENT","Parent");
define("_ROOT","Root");
define("_UCOMMENT","Comment");
define("_ALLOWEDHTML","Allowed HTML:");
define("_POSTANON","Post Anonymously");
define("_EXTRANS","Extrans (html tags to text)");
define("_HTMLFORMATED","HTML Formated");
define("_PLAINTEXT","Plain Old Text");
define("_ONN","on...");
define("_SUBJECT","Subject");
define("_SURVEYCOM","Survey Comment Post");
define("_SURVEYCOMPRE","Survey Comment Post Preview");
define("_NOTRIGHT","Something is not right with passing a variable to this function. This message is just to keep things from messing up down the road");
define("_DIRECTCOM","Direct Survey Comment...");
define("_SENDAMSG","Send a Message");
define("_PASTSURVEYS","Past Surveys");



define("_LVOTES","votes");
define("_TOTALVOTES","Total Votes:");
define("_VOTING","Voting Booth");
define("_OTHERPOLLS","Other Polls");
define("_CURRENTSURVEY","Current Survey");
define("_CURRENTPOLLRESULTS","Current Poll Results");
define("_PREVIEW","Preview");
define("_REFRESH","Refresh");
define("_SURVEYS","Surveys");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>
